@@ -527,7 +527,7 @@ class TransportMappingLayer:
     def peer_abort_indication(self):
         pass
 
-    def protocol_abort_indication(self, diagnostics):
+    def protocol_abort_indication(self, diagnostics=None):
         pass
 
     ###########################################################################
